@@ -82,5 +82,10 @@ def dev(create_venv: bool = True):
     os.system(command)
 
 
+@app.command()
+def version():
+    typer.echo("5")
+
+
 if __name__ == "__main__":
     app()
